==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/bean/MaterialacceptancedetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购材料验收明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_materialacceptancedetail")
public class MaterialacceptancedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="materialacceptance_id")
    private Long materialacceptanceId; // 材料验收主键
    @TableField(value="material_id")
    private Long materialId; // 原材类品种主键
    @TableField(value="material_name")
    private String materialName; // 原材类品种名称
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="material_tax")
    private BigDecimal materialTax; // 材料税额
    @TableField(value="freight_rate")
    private BigDecimal freightRate; // 运费税率
    @TableField(value="materialplan_id")
    private Long materialplanId; // 定料计划主键
    @TableField(value="supplierinfo_id")
    private Long supplierinfoId; // 供应商基本档案主键
    @TableField(value="supplierinfo_name")
    private String supplierinfoName; // 供应商基本档案名称
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="shippers_vehicle_id")
    private Long shippersVehicleId; // 运输车辆主键
    @TableField(value="shippers_vehicle_name")
    private String shippersVehicleName; // 运输车辆名称
    @TableField(value="purchasereceipt_id")
    private long purchasereceiptId;//收货单ID
    @TableField(value="money")
    private BigDecimal money; // 金额  单价*数量-税额
    @TableField(value="receipt_date")
    private Date  receiptDate;  //收货日期
    @TableField(value="total")
    private BigDecimal total; // 总计  单价*数量
    @TableField(value="material_tax_rate")
    private Integer materialTaxRate; //材料税率


    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }

    public Integer getMaterialTaxRate() {
        return materialTaxRate;
    }

    public void setMaterialTaxRate(Integer materialTaxRate) {
        this.materialTaxRate = materialTaxRate;
    }

    public Date getReceiptDate() {
        return receiptDate;
    }

    public void setReceiptDate(Date receiptDate) {
        this.receiptDate = receiptDate;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }

    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }

    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }

    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }
    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }

    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }
}

==> ejc-purchasingmanagement-impl-3.0.0-20220611.073322-111-sources.jar: com/ejianc/business/purchasingmanagement/bean/MaterialacceptancedetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购材料验收明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_materialacceptancedetail")
public class MaterialacceptancedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="materialacceptance_id")
    private Long materialacceptanceId; // 材料验收主键
    @TableField(value="material_id")
    private Long materialId; // 原材类品种主键
    @TableField(value="material_name")
    private String materialName; // 原材类品种名称
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="material_tax")
    private BigDecimal materialTax; // 材料税额
    @TableField(value="freight_rate")
    private BigDecimal freightRate; // 运费税率
    @TableField(value="materialplan_id")
    private Long materialplanId; // 定料计划主键
    @TableField(value="supplierinfo_id")
    private Long supplierinfoId; // 供应商基本档案主键
    @TableField(value="supplierinfo_name")
    private String supplierinfoName; // 供应商基本档案名称
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="shippers_vehicle_id")
    private Long shippersVehicleId; // 运输车辆主键
    @TableField(value="shippers_vehicle_name")
    private String shippersVehicleName; // 运输车辆名称
    @TableField(value="purchasereceipt_id")
    private long purchasereceiptId;//收货单ID
    @TableField(value="money")
    private BigDecimal money; // 金额  单价*数量-税额
    @TableField(value="receipt_date")
    private Date  receiptDate;  //收货日期
    @TableField(value="total")
    private BigDecimal total; // 总计  单价*数量
    @TableField(value="material_tax_rate")
    private BigDecimal materialTaxRate; //材料税率


    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }

    public BigDecimal getMaterialTaxRate() {
        return materialTaxRate;
    }

    public void setMaterialTaxRate(BigDecimal materialTaxRate) {
        this.materialTaxRate = materialTaxRate;
    }

    public Date getReceiptDate() {
        return receiptDate;
    }

    public void setReceiptDate(Date receiptDate) {
        this.receiptDate = receiptDate;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }

    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }

    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }

    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }
    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }

    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }
}
